@@ -499,6 +499,17 @@ public class TTable implements Closeable {
         return snapshotFilter.getScanner(tsscan, transaction);
     }
 
+    /**
+    * Return the raw HBase table
+    *
+    * This is needed to resolve API incompatibilities between HBase 2 and 3 in Phoenix.
+    *
+    * @return the backing table
+    */
+    public Table getHBaseTable() {
+       return table;
+    }
+
     /**
      *
      * @return array of byte
