@@ -20,7 +20,7 @@ package org.apache.omid.transaction;
 import static org.apache.omid.transaction.CellUtils.hasCell;
 import static org.apache.omid.transaction.CellUtils.hasShadowCell;
 import static org.junit.Assert.assertEquals;
-import static org.mockito.Matchers.any;
+import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.spy;
 import static org.testng.Assert.assertTrue;
